
# Metamodel schema


A metamodel for defining biolink related schemas


### Classes

 * [Element](Element.md) - a named element in the model
    * definition
       * class_definition
       * slot_definition
    * schema_definition
    * subset_definition
    * type_definition
 * [Example](Example.md) - usage example and description

### Mixins


### Slots

 * [examples](examples.md) - example usages of an element

### Types


#### Built in

 * **Bool**
 * **ElementIdentifier**
 * **NCName**
 * **NodeIdentifier**
 * **URI**
 * **URIorCURIE**
 * **XSDDate**
 * **XSDDateTime**
 * **XSDTime**
 * **float**
 * **int**
 * **str**

#### Defined

 * [String](types/String.md)  (**str**)  - A character string
